pkgconfig: Python interface to pkg-config
=========================================

Description
-----------

Pkgconfig is a Python module to interface with the pkg-config command
line tool.

License
-------

MIT License


Upstream Contact
----------------

https://github.com/matze/pkgconfig
